summaryrefslogtreecommitdiffstats
path: root/src/uca-grabber.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/uca-grabber.h')
-rw-r--r--src/uca-grabber.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/uca-grabber.h b/src/uca-grabber.h
index e8b422a..f30233b 100644
--- a/src/uca-grabber.h
+++ b/src/uca-grabber.h
@@ -36,38 +36,38 @@ enum uca_grabber_constants {
*
* \return UCA_ERR_INIT_NOT_FOUND if grabber is not found or could not be initialized
*/
-typedef uint32_t (*uca_grabber_init) (struct uca_grabber **grabber);
+typedef uint32_t (*uca_grabber_init) (struct uca_grabber_priv **grabber);
/**
* Free frame grabber resouces.
*/
-typedef uint32_t (*uca_grabber_destroy) (struct uca_grabber *grabber);
+typedef uint32_t (*uca_grabber_destroy) (struct uca_grabber_priv *grabber);
/**
* Set a frame grabber property.
*
* \param[in] prop Name of the property as defined in uca_grabber_constants
*
* \return UCA_ERR_PROP_INVALID if property is not supported on the frame
* grabber or UCA_ERR_PROP_VALUE_OUT_OF_RANGE if value cannot be set.
*/
-typedef uint32_t (*uca_grabber_set_property) (struct uca_grabber *grabber, enum uca_grabber_constants prop, void *data);
+typedef uint32_t (*uca_grabber_set_property) (struct uca_grabber_priv *grabber, enum uca_grabber_constants prop, void *data);
/**
* Get a frame grabber property.
*
* \param[in] prop Name of the property as defined in uca_grabber_constants
*
* \return UCA_ERR_PROP_INVALID if property is not supported on the frame grabber
*/
-typedef uint32_t (*uca_grabber_get_property) (struct uca_grabber *grabber, enum uca_grabber_constants prop, void *data);
+typedef uint32_t (*uca_grabber_get_property) (struct uca_grabber_priv *grabber, enum uca_grabber_constants prop, void *data);
/**
* Allocate buffers with current width, height and bitdepth.
*
* \warning Subsequent changes of width and height might corrupt memory.
*/
-typedef uint32_t (*uca_grabber_alloc) (struct uca_grabber *grabber, uint32_t pixel_size, uint32_t n_buffers);
+typedef uint32_t (*uca_grabber_alloc) (struct uca_grabber_priv *grabber, uint32_t pixel_size, uint32_t n_buffers);
/**
* Begin acquiring frames.
@@ -76,17 +76,17 @@ typedef uint32_t (*uca_grabber_alloc) (struct uca_grabber *grabber, uint32_t pix
*
* \param[in] async Grab asynchronous if true
*/
-typedef uint32_t (*uca_grabber_acquire) (struct uca_grabber *grabber, int32_t n_frames);
+typedef uint32_t (*uca_grabber_acquire) (struct uca_grabber_priv *grabber, int32_t n_frames);
/**
* Stop acquiring frames.
*/
-typedef uint32_t (*uca_grabber_stop_acquire) (struct uca_grabber *grabber);
+typedef uint32_t (*uca_grabber_stop_acquire) (struct uca_grabber_priv *grabber);
/**
* Issue a software trigger signal.
*/
-typedef uint32_t (*uca_grabber_trigger) (struct uca_grabber *grabber);
+typedef uint32_t (*uca_grabber_trigger) (struct uca_grabber_priv *grabber);
/**
* Grab a frame.
@@ -97,30 +97,30 @@ typedef uint32_t (*uca_grabber_trigger) (struct uca_grabber *grabber);
*
* \param[out] frame_number Number of the grabbed frame
*/
-typedef uint32_t (*uca_grabber_grab) (struct uca_grabber *grabber, void **buffer, uint64_t *frame_number);
+typedef uint32_t (*uca_grabber_grab) (struct uca_grabber_priv *grabber, void **buffer, uint64_t *frame_number);
/**
* Register callback for given frame grabber. To actually start receiving
- * frames, call uca_grabber_acquire().
+ * frames, call uca_grabber_priv_acquire().
*
* \param[in] grabber The grabber for which the callback should be installed
*
* \param[in] cb Callback function for when a frame arrived
*/
-typedef uint32_t (*uca_grabber_register_callback) (struct uca_grabber *grabber, uca_cam_grab_callback cb, void *meta_data, void *user);
+typedef uint32_t (*uca_grabber_register_callback) (struct uca_grabber_priv *grabber, uca_cam_grab_callback cb, void *meta_data, void *user);
/**
* Represents a frame grabber abstraction, that concrete frame grabber
* implementations must implement.
*
* A uca_grabber_t structure is never used directly but only via the
* uca_camera_t interface in order to keep certain duplicated properties in sync
* (e.g. image dimensions can be set on frame grabber and camera).
*/
-typedef struct uca_grabber {
- struct uca_grabber *next;
+typedef struct uca_grabber_priv {
+ struct uca_grabber_priv *next;
/* Function pointers to grabber-specific methods */
uca_grabber_destroy destroy;
@@ -135,9 +135,9 @@ typedef struct uca_grabber {
/* Private */
uca_cam_grab_callback callback;
- bool synchronous; /**< if true uca_grabber_grab() blocks until image is transferred */
+ bool synchronous; /**< if true uca_grabber_priv_grab() blocks until image is transferred */
void *user;
-} uca_grabber_t;
+} uca_grabber_priv_t;
@@ -36,38 +36,38 @@ enum uca_grabber_constants {
* Set a frame grabber property.
*
- * \param[in] prop Name of the property as defined in uca_grabber_constants
+ * \param[in] prop Name of the property as defined in uca_grabber_priv_constants
*
* \return UCA_ERR_PROP_INVALID if property is not supported on the frame
@@ -36,38 +36,38 @@ enum uca_grabber_constants {
* Get a frame grabber property.
*
- * \param[in] prop Name of the property as defined in uca_grabber_constants
+ * \param[in] prop Name of the property as defined in uca_grabber_priv_constants
*
* \return UCA_ERR_PROP_INVALID if property is not supported on the frame grabber
@@ -97,30 +97,30 @@ typedef uint32_t (*uca_grabber_trigger) (struct uca_grabber *grabber);
* implementations must implement.
*
- * A uca_grabber_t structure is never used directly but only via the
+ * A uca_grabber_priv_t structure is never used directly but only via the
* uca_camera_t interface in order to keep certain duplicated properties in sync
* (e.g. image dimensions can be set on frame grabber and camera).